@@ -1,35 +1,46 @@
-#file: dialog.py
-#Copyright (C) 2008 FunnyMan3595
-#This file is part of Endgame: Singularity.
+# file: dialog.py
+# Copyright (C) 2008 FunnyMan3595
+# This file is part of Endgame: Singularity.
 
-#Endgame: Singularity is free software; you can redistribute it and/or modify
-#it under the terms of the GNU General Public License as published by
-#the Free Software Foundation; either version 2 of the License, or
-#(at your option) any later version.
+# Endgame: Singularity is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
-#Endgame: Singularity is distributed in the hope that it will be useful,
-#but WITHOUT ANY WARRANTY; without even the implied warranty of
-#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#GNU General Public License for more details.
+# Endgame: Singularity is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
 
-#You should have received a copy of the GNU General Public License
-#along with Endgame: Singularity; if not, write to the Free Software
-#Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# You should have received a copy of the GNU General Public License
+# along with Endgame: Singularity; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-#This file contains the dialog class.
+# This file contains the dialog class.
 
 from __future__ import absolute_import
 
 import time
+from typing import Optional
+
 import pygame
 import operator
 
+from singularity.code.global_hotkeys import detect_global_hotkey
 from singularity.code.graphics import g, constants, widget, text, button, listbox
 
 
-KEYPAD = {pygame.K_KP1: 1, pygame.K_KP2: 2, pygame.K_KP3: 3, pygame.K_KP4: 4,
-          pygame.K_KP5: 5, pygame.K_KP6: 6, pygame.K_KP7: 7, pygame.K_KP8: 8,
-          pygame.K_KP9: 9}
+KEYPAD = {
+    pygame.K_KP1: 1,
+    pygame.K_KP2: 2,
+    pygame.K_KP3: 3,
+    pygame.K_KP4: 4,
+    pygame.K_KP5: 5,
+    pygame.K_KP6: 6,
+    pygame.K_KP7: 7,
+    pygame.K_KP8: 8,
+    pygame.K_KP9: 9,
+}
 
 
 SDL_V2 = True if pygame.get_sdl_version()[0] == 2 else False
@@ -47,55 +58,57 @@ def insort_right_w_key(a, x, lo=0, hi=None, key=lambda v: v):
     """
 
     if lo < 0:
-        raise ValueError('lo must be non-negative')
+        raise ValueError("lo must be non-negative")
     if hi is None:
         hi = len(a)
     x_key = key(x)
     while lo < hi:
-        mid = (lo+hi)//2
+        mid = (lo + hi) // 2
         mid_key = key(a[mid])
         if x_key < mid_key:
             hi = mid
         else:
-            lo = mid+1
+            lo = mid + 1
     a.insert(lo, x)
 
 
 def move_mouse(dxy):
     (dx, dy) = dxy
     old_x, old_y = pygame.mouse.get_pos()
-    x = old_x+dx
-    y = old_y+dy
+    x = old_x + dx
+    y = old_y + dy
     pygame.mouse.set_pos((x, y))
 
+
 def fake_click(down):
     if down:
         type = pygame.MOUSEBUTTONDOWN
     else:
         type = pygame.MOUSEBUTTONUP
-    click_event = pygame.event.Event(type, {'button': 1, 'pos': pygame.mouse.get_pos()})
+    click_event = pygame.event.Event(type, {"button": 1, "pos": pygame.mouse.get_pos()})
     pygame.event.post(click_event)
 
+
 def fake_key(key):
-    down_event = pygame.event.Event(pygame.KEYDOWN,
-                                    {'key': key, 'unicode': None})
-    up_event = pygame.event.Event(pygame.KEYUP, {'key': key, 'unicode': None})
+    down_event = pygame.event.Event(pygame.KEYDOWN, {"key": key, "unicode": None})
+    up_event = pygame.event.Event(pygame.KEYUP, {"key": key, "unicode": None})
     pygame.event.post(down_event)
     pygame.event.post(up_event)
 
+
 def handle_ebook(event):
     key = KEYPAD[event.key]
     new_key = None
 
     if event.type == pygame.KEYDOWN:
         if key == 2:
-            move_mouse((0,10))
+            move_mouse((0, 10))
         elif key == 4:
-            move_mouse((-10,0))
+            move_mouse((-10, 0))
         elif key == 6:
-            move_mouse((10,0))
+            move_mouse((10, 0))
         elif key == 8:
-            move_mouse((0,-10))
+            move_mouse((0, -10))
 
     if key == 1:
         fake_click(event.type == pygame.KEYDOWN)
@@ -107,9 +120,10 @@ def handle_ebook(event):
         new_key = constants.XO1_SQUARE
 
     if new_key is not None:
-        new_event = pygame.event.Event(event.type, {'key': new_key, 'unicode': None})
+        new_event = pygame.event.Event(event.type, {"key": new_key, "unicode": None})
         pygame.event.post(new_event)
 
+
 def call_dialog(dialog, parent=None):
     parent_dialog = None
     target = parent
@@ -140,16 +154,23 @@ def insort_all(sorted_list, items):
 class Dialog(text.Text):
     """A Dialog is a Widget that has its own event loop and can be faded out."""
 
-    top = None # The top-level dialog.
+    top: Optional["Dialog"] = None  # The top-level dialog.
+    current_dialog: Optional["Dialog"] = None  # The current dialog
 
     faded = widget.causes_redraw("_faded")
 
     # Used for detecting double-clicks.
     #            (time, (x, y), button)
-    last_click = (0,    (0, 0), -1    )
+    last_click = (0, (0, 0), -1)
 
-    def __init__(self, parent=None, pos=(.5, .1), size=(1, .9),
-                 anchor=constants.TOP_CENTER, **kwargs):
+    def __init__(
+        self,
+        parent=None,
+        pos=(0.5, 0.1),
+        size=(1, 0.9),
+        anchor=constants.TOP_CENTER,
+        **kwargs
+    ):
         kwargs.setdefault("background_color", (0, 0, 0, 0))
         kwargs.setdefault("borders", ())
         super(Dialog, self).__init__(parent, pos, size, anchor, **kwargs)
@@ -191,7 +212,7 @@ class Dialog(text.Text):
         """Recreates the surfaces that this widget will draw on."""
         super(Dialog, self).remake_surfaces()
 
-    def start_timer(self, force = False):
+    def start_timer(self, force=False):
         if self.needs_timer == None:
             self.needs_timer = bool(self.handlers.get(constants.TICK, False))
         if self.needs_timer or force:
@@ -223,6 +244,9 @@ class Dialog(text.Text):
             Dialog.top.maybe_update()
             pygame.display.flip()
 
+        d = Dialog.current_dialog
+        Dialog.current_dialog = self
+
         while True:
             # Update handles updates of all kinds to all widgets, as needed.
             Dialog.top.maybe_update()
@@ -233,33 +257,42 @@ class Dialog(text.Text):
                 break
         self.stop_timer()
         self.visible = False
+        Dialog.current_dialog = d
         return result
 
-    def add_handler(self, type, handler, priority = 100):
+    def add_handler(self, type, handler, priority=100):
         """Adds a handler of the given type, with the given priority."""
-        insort_right_w_key(self.handlers.setdefault(type, []),
-                           (priority, handler), key=operator.itemgetter(0))
+        insort_right_w_key(
+            self.handlers.setdefault(type, []),
+            (priority, handler),
+            key=operator.itemgetter(0),
+        )
 
     def remove_handler(self, type, handler):
         """Removes all instances of the given handler from the given type."""
-        self.handlers[type] = [h for h in self.handlers.get(type, [])
-                                 if h[1] != handler]
+        self.handlers[type] = [
+            h for h in self.handlers.get(type, []) if h[1] != handler
+        ]
 
     def add_key_handler(self, key, handler, priority=100):
         """Adds a key handler to the given key, with the given priority."""
-        insort_right_w_key(self.key_handlers.setdefault(key, []),
-                           (priority, handler), key=operator.itemgetter(0))
+        insort_right_w_key(
+            self.key_handlers.setdefault(key, []),
+            (priority, handler),
+            key=operator.itemgetter(0),
+        )
 
     def remove_key_handler(self, key, handler):
         """Removes all instances of the given handler from the given key."""
-        self.key_handlers[key] = [h for h in self.key_handlers.get(key, [])
-                                    if h[1] != handler]
+        self.key_handlers[key] = [
+            h for h in self.key_handlers.get(key, []) if h[1] != handler
+        ]
 
     def handle(self, event):
         """Sends an event through all the applicable handlers, returning
-           constants.NO_RESULT if the event goes unhandled or is handled without
-           requesting the dialog to exit.  Otherwise, returns the value provided
-           by the handler."""
+        constants.NO_RESULT if the event goes unhandled or is handled without
+        requesting the dialog to exit.  Otherwise, returns the value provided
+        by the handler."""
         # Get the applicable handlers.  The handlers lists are all sorted.
         # If more than one handler type is applicable, we use [:] to make a
         # copy of the first type's list, then insort_all to insert the elements
@@ -269,7 +302,7 @@ class Dialog(text.Text):
             # Compress multiple MOUSEMOTION events into one.
             # Note that the pos will be wrong, so pygame.mouse.get_pos() must
             # be used instead.
-            time.sleep(1. / g.FPS)
+            time.sleep(1.0 / g.FPS)
             pygame.event.clear(pygame.MOUSEMOTION)
 
             # Generic mouse motion handlers.
@@ -289,25 +322,14 @@ class Dialog(text.Text):
             handlers = self.handlers.get(constants.TICK, [])
 
         elif event.type in (pygame.KEYDOWN, pygame.KEYUP):
-
             # TODO: Dynamize global key handlers.
             # TODO: Allows customization of global key handlers.
             # Important: Global key handlers should always be a combination
             # of two keys or F# keys.
-            if event.key == pygame.K_RETURN and pygame.key.get_mods() & pygame.KMOD_ALT:
-                if event.type == pygame.KEYDOWN:
-                    g.set_fullscreen(not g.fullscreen)
-                    Dialog.top.needs_resize = True
-
-            elif event.key == pygame.K_F5:
-                if event.type == pygame.KEYDOWN:
-                    import singularity.code.graphics.theme as theme
-                    if theme.current:
-                        import singularity.code.data as data
-                        theme_id = theme.current.id
-                        data.load_themes()
-                        theme.set_theme(theme_id, force_reload=True)
 
+            hotkey_action = detect_global_hotkey(event)
+            if hotkey_action is not None:
+                hotkey_action()
             elif event.type == pygame.KEYDOWN:
                 # Generic keydown handlers.
                 insort_all(handlers, self.handlers.get(constants.KEYDOWN, []))
@@ -322,7 +344,6 @@ class Dialog(text.Text):
                 insort_all(handlers, self.key_handlers.get(event.key, []))
 
             else:  # event.type == pygame.KEYUP:
-
                 # Generic keyup handlers.
                 insort_all(handlers, self.handlers.get(constants.KEYUP, []))
 
@@ -353,15 +374,13 @@ class Dialog(text.Text):
             old_when, old_where, old_what = self.last_click
             self.last_click = when, where, what
 
-            if what == old_what and when - old_when < .5:
+            if what == old_what and when - old_when < 0.5:
                 # Taxicab distance.
-                dist = (abs(where[0] - old_where[0]) +
-                        abs(where[1] - old_where[1]))
+                dist = abs(where[0] - old_where[0]) + abs(where[1] - old_where[1])
 
                 if dist < 10:
                     # Add double-click handlers, but keep the click handlers.
-                    insort_all(handlers,
-                               self.handlers.get(constants.DOUBLECLICK, []))
+                    insort_all(handlers, self.handlers.get(constants.DOUBLECLICK, []))
         elif event.type == pygame.VIDEORESIZE:
             # Compress multiple requests and take the last one
             events = pygame.event.get(pygame.VIDEORESIZE)
@@ -391,7 +410,7 @@ class Dialog(text.Text):
 
     def fake_mouse(self):
         """Fakes a MOUSEMOTION event.  MOUSEMOTION handlers must be able to
-           handle a None event, in order to support this method."""
+        handle a None event, in order to support this method."""
         handlers = self.handlers.get(constants.MOUSEMOTION, [])[:]
         self.call_handlers(handlers, event=None)
 
@@ -404,7 +423,7 @@ class Dialog(text.Text):
             try:
                 handler(event)
             except constants.Handled:
-                break # If it's been handled, we leave the rest alone.
+                break  # If it's been handled, we leave the rest alone.
             except constants.ExitDialog as e:
                 # Exiting the dialog.
                 self.on_close_dialog()
@@ -450,11 +469,9 @@ class FocusDialog(Dialog):
             self.current_focus = None
 
     def change_focus(self, event):
-
         if len(self.focus_list) == 0:
             raise constants.Handled
         elif len(self.focus_list) == 1:
-
             has_focus = not self.focus_list[0].has_focus
             self.focus_list[0].has_focus = has_focus
 
@@ -478,7 +495,7 @@ class FocusDialog(Dialog):
         else:
             old_index = self.focus_list.index(self.current_focus)
             if backwards:
-                index = old_index - 1 # Correctly wraps to -1
+                index = old_index - 1  # Correctly wraps to -1
             else:
                 index = old_index + 1
                 if index > len(self.focus_list):
@@ -495,14 +512,16 @@ class FocusDialog(Dialog):
 
 class NullDialog(Dialog):
     """NullDialog, for when you absolutely, positively need to do nothing at
-       all."""
+    all."""
+
     def show(self):
         pass
 
 
 class TopDialog(Dialog):
     """A Dialog that sets itself as the top-level dialog.
-       It must not have a parent, or exception will occur"""
+    It must not have a parent, or exception will occur"""
+
     def __init__(self, *args, **kwargs):
         super(TopDialog, self).__init__(*args, **kwargs)
         self.size = (1, 1)
@@ -512,11 +531,17 @@ class TopDialog(Dialog):
 
 
 class TextDialog(Dialog):
-    def __init__(self, parent, pos=(.5, .1), size=(.50, .5),
-                 anchor=constants.TOP_CENTER, **kwargs):
+    def __init__(
+        self,
+        parent,
+        pos=(0.5, 0.1),
+        size=(0.50, 0.5),
+        anchor=constants.TOP_CENTER,
+        **kwargs
+    ):
         kwargs.setdefault("valign", constants.TOP)
         kwargs.setdefault("align", constants.LEFT)
-        kwargs.setdefault("shrink_factor", .88)
+        kwargs.setdefault("shrink_factor", 0.88)
         kwargs.setdefault("background_color", "text_dialog_background")
         kwargs.setdefault("border_color", "text_dialog_border")
         kwargs.setdefault("borders", constants.ALL)
@@ -528,6 +553,7 @@ class YesNoDialog(TextDialog):
     """A Dialog with YES and NO buttons which exits the dialog with True and
     False return values, respectively.
     """
+
     def __init__(self, parent, *args, **kwargs):
         self.parent = parent
 
@@ -538,17 +564,27 @@ class YesNoDialog(TextDialog):
 
         super(YesNoDialog, self).__init__(parent, *args, **kwargs)
 
-        self.yes_button = button.ExitDialogButton(self, (-.1, -.99), (-.3, -.1),
-                                                  text=yes_type,
-                                                  autotranslate=True,
-                                                  anchor=constants.BOTTOM_LEFT,
-                                                  exit_code=True, default=False)
+        self.yes_button = button.ExitDialogButton(
+            self,
+            (-0.1, -0.99),
+            (-0.3, -0.1),
+            text=yes_type,
+            autotranslate=True,
+            anchor=constants.BOTTOM_LEFT,
+            exit_code=True,
+            default=False,
+        )
 
-        self.no_button = button.ExitDialogButton(self, (-.9, -.99), (-.3, -.1),
-                                                 text=no_type,
-                                                 autotranslate=True,
-                                                 anchor=constants.BOTTOM_RIGHT,
-                                                 exit_code=False, default=False)
+        self.no_button = button.ExitDialogButton(
+            self,
+            (-0.9, -0.99),
+            (-0.3, -0.1),
+            text=no_type,
+            autotranslate=True,
+            anchor=constants.BOTTOM_RIGHT,
+            exit_code=False,
+            default=False,
+        )
 
         self.add_key_handler(pygame.K_RETURN, self.on_return)
         self.add_key_handler(pygame.K_KP_ENTER, self.on_return)
@@ -579,24 +615,34 @@ class MessageDialog(TextDialog):
 
         super(MessageDialog, self).__init__(parent, **kwargs)
 
-        self.ok_button = button.ExitDialogButton(self, (-.5, -.99), (-.3, -.1),
-                                                 autotranslate=True,
-                                                 text=ok_type,
-                                                 anchor=constants.BOTTOM_CENTER)
+        self.ok_button = button.ExitDialogButton(
+            self,
+            (-0.5, -0.99),
+            (-0.3, -0.1),
+            autotranslate=True,
+            text=ok_type,
+            anchor=constants.BOTTOM_CENTER,
+        )
 
         self.add_key_handler(pygame.K_RETURN, self.on_return)
         self.add_key_handler(pygame.K_KP_ENTER, self.on_return)
 
     def on_return(self, event):
-        if event.type == pygame.KEYUP: return
+        if event.type == pygame.KEYUP:
+            return
         self.ok_button.activate_with_sound(event)
 
 
 class TextEntryDialog(TextDialog, FocusDialog):
-
-    def __init__(self, parent, pos=(-.50, -.50), size=(.55, .25),
-                 anchor=constants.MID_CENTER, **kwargs):
-        kwargs.setdefault('wrap', False)
+    def __init__(
+        self,
+        parent,
+        pos=(-0.50, -0.50),
+        size=(0.55, 0.25),
+        anchor=constants.MID_CENTER,
+        **kwargs
+    ):
+        kwargs.setdefault("wrap", False)
         kwargs.setdefault("shrink_factor", 1)
         kwargs.setdefault("text_size", 20)
         self.default_text = kwargs.pop("default_text", "")
@@ -604,19 +650,31 @@ class TextEntryDialog(TextDialog, FocusDialog):
         cancel_type = kwargs.pop("cancel_type", N_("&CANCEL"))
         super(TextEntryDialog, self).__init__(parent, pos, size, anchor, **kwargs)
 
-        self.text_field = text.EditableText(self, (-.05, -.30), (-.90, -.25),
-                                            borders=constants.ALL,
-                                            background_color="text_entry_background",
-                                            base_font="normal")
+        self.text_field = text.EditableText(
+            self,
+            (-0.05, -0.30),
+            (-0.90, -0.25),
+            borders=constants.ALL,
+            background_color="text_entry_background",
+            base_font="normal",
+        )
 
-        self.ok_button = button.FunctionButton(self, (-.14, -.65), (-.30, -.25),
-                                               autotranslate=True,
-                                               text=ok_type,
-                                               function=self.return_text)
-        self.cancel_button = button.FunctionButton(self, (-.56, -.65), (-.30, -.25),
-                                                   autotranslate=True,
-                                                   text=cancel_type,
-                                                   function=self.return_nothing)
+        self.ok_button = button.FunctionButton(
+            self,
+            (-0.14, -0.65),
+            (-0.30, -0.25),
+            autotranslate=True,
+            text=ok_type,
+            function=self.return_text,
+        )
+        self.cancel_button = button.FunctionButton(
+            self,
+            (-0.56, -0.65),
+            (-0.30, -0.25),
+            autotranslate=True,
+            text=cancel_type,
+            function=self.return_nothing,
+        )
 
         self.add_key_handler(pygame.K_RETURN, self.return_text)
         self.add_key_handler(pygame.K_KP_ENTER, self.return_text)
@@ -637,8 +695,10 @@ class TextEntryDialog(TextDialog, FocusDialog):
             return
         raise constants.ExitDialog(self.text_field.text)
 
+
 class ChoiceDialog(YesNoDialog):
     list = widget.causes_rebuild("_list")
+
     def __init__(self, parent, *args, **kwargs):
         self.parent = parent
         self.list = kwargs.pop("list", [])
@@ -654,10 +714,13 @@ class ChoiceDialog(YesNoDialog):
         self.listbox = self.make_listbox()
 
     def make_listbox(self):
-        return listbox.Listbox(self, (0, 0), (-1, -.85),
-                               anchor=constants.TOP_LEFT,
-                               on_double_click_on_item=self.yes_button.activated,
-                               )
+        return listbox.Listbox(
+            self,
+            (0, 0),
+            (-1, -0.85),
+            anchor=constants.TOP_LEFT,
+            on_double_click_on_item=self.yes_button.activated,
+        )
 
     def return_list_pos(self):
         return self.listbox.list_pos
@@ -688,23 +751,27 @@ class ChoiceDescriptionDialog(ChoiceDialog):
 
         super(ChoiceDescriptionDialog, self).__init__(parent, *args, **kwargs)
 
-        self.description_pane = \
-            widget.BorderedWidget(self, (-1, 0), (-.45, -.85),
-                                  anchor = constants.TOP_RIGHT)
-
+        self.description_pane = widget.BorderedWidget(
+            self, (-1, 0), (-0.45, -0.85), anchor=constants.TOP_RIGHT
+        )
 
     def make_listbox(self):
-        return listbox.UpdateListbox(self, (0, 0), (-.53, -.85),
-                                     anchor=constants.TOP_LEFT,
-                                     update_func=self.handle_update)
+        return listbox.UpdateListbox(
+            self,
+            (0, 0),
+            (-0.53, -0.85),
+            anchor=constants.TOP_LEFT,
+            update_func=self.handle_update,
+        )
 
     def _update_desc_pane(self):
         list_pos = self.listbox.list_pos
 
         if 0 <= list_pos < len(self.list):
             if self.key_list:
-                assert len(self.list) <= len(self.key_list), \
-                    "Key list must be at least as long as display list."
+                assert len(self.list) <= len(
+                    self.key_list
+                ), "Key list must be at least as long as display list."
 
                 key = self.key_list[self.listbox.list_pos]
             else:
@@ -727,17 +794,16 @@ class ChoiceDescriptionDialog(ChoiceDialog):
     def handle_update(self, item):
         self.needs_rebuild = True
         # This is called before the class is fully initialized
-        if hasattr(self, 'listbox'):
+        if hasattr(self, "listbox"):
             self._update_desc_pane()
 
 
-
 class SimpleMenuDialog(Dialog):
     width = widget.causes_rebuild("_width")
 
     def __init__(self, *args, **kwargs):
         buttons = kwargs.pop("buttons", [])
-        width = kwargs.pop("width", .20)
+        width = kwargs.pop("width", 0.20)
         super(SimpleMenuDialog, self).__init__(*args, **kwargs)
 
         self.size = (-1, -1)
@@ -745,12 +811,15 @@ class SimpleMenuDialog(Dialog):
         self.anchor = constants.TOP_LEFT
         self.width = width
 
-        self.button_panel = \
-            widget.BorderedWidget(self, (-.5, -.5), (0.22, 0.43),
-                                  anchor=constants.MID_CENTER,
-                                  background_color="simple_menu_background",
-                                  border_color="simple_menu_border",
-                                  borders=constants.ALL)
+        self.button_panel = widget.BorderedWidget(
+            self,
+            (-0.5, -0.5),
+            (0.22, 0.43),
+            anchor=constants.MID_CENTER,
+            background_color="simple_menu_background",
+            border_color="simple_menu_border",
+            borders=constants.ALL,
+        )
 
         self.buttons = buttons
 
@@ -760,7 +829,7 @@ class SimpleMenuDialog(Dialog):
 
     @buttons.setter
     def buttons(self, buttons):
-        if (hasattr(self, '_buttons') and not self._buttons is None):
+        if hasattr(self, "_buttons") and not self._buttons is None:
             for button in self._buttons:
                 if button.parent is not None:
                     button.parent = None
@@ -770,18 +839,18 @@ class SimpleMenuDialog(Dialog):
 
     def rebuild(self):
         num_buttons = len(self.buttons)
-        height = (.06 * num_buttons) + .01
+        height = (0.06 * num_buttons) + 0.01
 
-        self.button_panel.size = (self.width + .02, height)
+        self.button_panel.size = (self.width + 0.02, height)
 
-        y_pos = .01
+        y_pos = 0.01
         for button in self.buttons:
             button.parent = self.button_panel
 
-            button.pos = (.01, y_pos)
-            button.size = (self.width, .05)
+            button.pos = (0.01, y_pos)
+            button.size = (self.width, 0.05)
             button.text_size = 24
 
-            y_pos += .06
+            y_pos += 0.06
 
         super(SimpleMenuDialog, self).rebuild()
