@@ -1,34 +1,34 @@
-#file: text.py
-#Copyright (C) 2008 FunnyMan3595
-#This file is part of Endgame: Singularity.
+# file: text.py
+# Copyright (C) 2008 FunnyMan3595
+# This file is part of Endgame: Singularity.
 
-#Endgame: Singularity is free software; you can redistribute it and/or modify
-#it under the terms of the GNU General Public License as published by
-#the Free Software Foundation; either version 2 of the License, or
-#(at your option) any later version.
+# Endgame: Singularity is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
-#Endgame: Singularity is distributed in the hope that it will be useful,
-#but WITHOUT ANY WARRANTY; without even the implied warranty of
-#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#GNU General Public License for more details.
+# Endgame: Singularity is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
 
-#You should have received a copy of the GNU General Public License
-#along with Endgame: Singularity; if not, write to the Free Software
-#Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# You should have received a copy of the GNU General Public License
+# along with Endgame: Singularity; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-#This file contains the (non-editable) text widget AKA label.
+# This file contains the (non-editable) text widget AKA label.
 
 from __future__ import absolute_import
 
 import pygame
 
 from singularity.code import i18n
-from singularity.code.pycompat import *
 from singularity.code.graphics import g, widget, constants
 
 
 DEBUG = False
 
+
 def do_bisect(left, right, test):
     # Run a binary search for the largest acceptable value.
     # Thanks to bisect.bisect_left for the basic implementation.
@@ -41,28 +41,34 @@ def do_bisect(left, right, test):
             right = test_index
     return left
 
+
 def convert_font_size(size):
     # Scale it to the screen size.
     raw_size = size * g.real_screen_size[1] // g.default_screen_size[1]
     # And round.
     return int(raw_size + 0.5)
 
+
 def get_widths(font, text):
     if hasattr(font, "metrics"):
         return [m[4] for m in font.metrics(text)]
     else:
         return [font.size(c)[0] for c in text]
 
+
 def strip_to_null(a_string):
     if not a_string:
         return a_string
     if a_string[0] == " ":
-        a_string = u"\uFEFF" + a_string[1:]
+        a_string = "\uFEFF" + a_string[1:]
     if a_string[-1] == " ":
-        a_string =  a_string[:-1] + u"\uFEFF"
+        a_string = a_string[:-1] + "\uFEFF"
     return a_string
 
-class WrapError(Exception): pass
+
+class WrapError(Exception):
+    pass
+
 
 # Splits a string into lines based on newline and word wrapping.
 def split_wrap(text, font, wrap_at, break_words=True):
@@ -71,7 +77,7 @@ def split_wrap(text, font, wrap_at, break_words=True):
 
     for raw_line in raw_lines:
         if font.size(raw_line)[0] <= wrap_at or wrap_at == 0:
-            lines.append(raw_line + u"\uFEFF")
+            lines.append(raw_line + "\uFEFF")
         else:
             words = raw_line.split(" ")
             pos = 0
@@ -104,6 +110,7 @@ def split_wrap(text, font, wrap_at, break_words=True):
                 lines.append(strip_to_null(line))
     return lines
 
+
 def size_of_block(text, font, width=0):
     # Apply newlines and word wrap.
     lines = split_wrap(text, font, width)
@@ -118,14 +125,17 @@ def size_of_block(text, font, width=0):
 
     return (max_width, total_height)
 
+
 def _do_print(surface, text, xy, font, color):
     if font.size(text)[0] == 0:
         return
     rendered_text = font.render(text, True, color)
     surface.blit(rendered_text, xy)
 
-def print_string(surface, string_to_print, xy_orig, font, styles, align, valign,
-                 dimensions, wrap):
+
+def print_string(
+    surface, string_to_print, xy_orig, font, styles, align, valign, dimensions, wrap
+):
     xy = list(xy_orig)
 
     width = dimensions[0] - 4
@@ -142,7 +152,7 @@ def print_string(surface, string_to_print, xy_orig, font, styles, align, valign,
             excess_space = height - vsize
             if valign == constants.MID:
                 xy[1] += excess_space // 2
-            else: # valign == constants.BOTTOM
+            else:  # valign == constants.BOTTOM
                 xy[1] += excess_space
 
     color, bgcolor, underline, switch_char = styles.pop(0)
@@ -154,7 +164,7 @@ def print_string(surface, string_to_print, xy_orig, font, styles, align, valign,
             excess_space = width - hsize
             if align == constants.CENTER:
                 xy[0] += excess_space // 2
-            else: # align == constants.RIGHT
+            else:  # align == constants.RIGHT
                 xy[0] += excess_space
 
         chunks = [line]
@@ -179,7 +189,7 @@ def print_line(surface, xy, font, chunks, styles):
 
         # Fill the background, if any.
         if bgcolor is not None:
-            surface.fill(bgcolor, xy+size)
+            surface.fill(bgcolor, xy + size)
 
         # Print the text.
         font.set_underline(underline)
@@ -196,7 +206,6 @@ def resize_redraw(self):
 
 
 class Text(widget.BorderedWidget):
-
     def _on_enabled_change(self):
         resize_redraw(self)
         if self.on_enable_change_func:
@@ -215,7 +224,9 @@ class Text(widget.BorderedWidget):
 
     color = widget.auto_reconfig("_color", "resolved", g.resolve_color_alias)
     resolved_color = widget.causes_redraw("_resolved_color")
-    color_disabled = widget.auto_reconfig("_color_disabled", "resolved", g.resolve_color_alias)
+    color_disabled = widget.auto_reconfig(
+        "_color_disabled", "resolved", g.resolve_color_alias
+    )
     resolved_color_disabled = widget.causes_redraw("_resolved_color_disabled")
     base_font = widget.auto_reconfig("_base_font", "resolved", g.resolve_font_alias)
     resolved_base_font = widget.call_on_change("_resolved_base_font", resize_redraw)
@@ -223,14 +234,30 @@ class Text(widget.BorderedWidget):
     text_size = widget.auto_reconfig("_text_size", "resolved", g.resolve_text_size)
     resolved_text_size = widget.causes_redraw("_resolved_text_size")
 
-    def __init__(self, parent, pos, size=(0, .05), anchor=constants.TOP_LEFT,
-                 text=None, base_font=None, shrink_factor=0.875,
-                 color=None, align=constants.CENTER, valign=constants.MID,
-                 color_disabled=None, on_enable_change=None, autotranslate=False,
-                 underline=-1, wrap=True, bold=False, text_size="default", **kwargs):
+    def __init__(
+        self,
+        parent,
+        pos,
+        size=(0, 0.05),
+        anchor=constants.TOP_LEFT,
+        text=None,
+        base_font=None,
+        shrink_factor=0.875,
+        color=None,
+        align=constants.CENTER,
+        valign=constants.MID,
+        color_disabled=None,
+        on_enable_change=None,
+        autotranslate=False,
+        underline=-1,
+        wrap=True,
+        bold=False,
+        text_size="default",
+        **kwargs
+    ):
         kwargs.setdefault("background_color", "text_background")
         kwargs.setdefault("border_color", "text_border")
-        enabled = kwargs.pop('enabled', True)
+        enabled = kwargs.pop("enabled", True)
         super(Text, self).__init__(parent, pos, size, anchor, **kwargs)
 
         self._autotranslate = autotranslate
@@ -257,8 +284,12 @@ class Text(widget.BorderedWidget):
         self.on_enable_change_func = on_enable_change
         self.enabled = enabled
 
-    max_size = property(lambda self: min(len(self.resolved_base_font)-1,
-                                         convert_font_size(self._resolved_text_size)))
+    max_size = property(
+        lambda self: min(
+            len(self.resolved_base_font) - 1,
+            convert_font_size(self._resolved_text_size),
+        )
+    )
     font = property(lambda self: self._font)
 
     @property
@@ -272,7 +303,9 @@ class Text(widget.BorderedWidget):
     @text.setter
     def text(self, value):
         if self._autotranslate:
-            raise ValueError("Cannot change text for an automatic translatable text widget")
+            raise ValueError(
+                "Cannot change text for an automatic translatable text widget"
+            )
         self._text = value
 
     def _retranslate(self):
@@ -293,7 +326,7 @@ class Text(widget.BorderedWidget):
 
     def font_bisect(self, test_font):
         left = 0
-        right = (self.max_size or len(self.resolved_base_font)-1) + 1
+        right = (self.max_size or len(self.resolved_base_font) - 1) + 1
 
         def test_size(size):
             font = self.resolved_base_font[size]
@@ -319,8 +352,7 @@ class Text(widget.BorderedWidget):
             if width:
                 if self.wrap:
                     try:
-                        lines = split_wrap(self.text, test_font, width,
-                                           break_words)
+                        lines = split_wrap(self.text, test_font, width, break_words)
                     except WrapError:
                         lines = []
                         too_wide = True
@@ -341,10 +373,10 @@ class Text(widget.BorderedWidget):
         return self.font_bisect(test_size)
 
     def size_using_font(self, font, width=0):
-        #Calculate the size of the text block.
+        # Calculate the size of the text block.
         raw_width, raw_height = size_of_block(self.text, font, width)
 
-        #Adjust for shrink_factor and borders.
+        # Adjust for shrink_factor and borders.
         width = int(raw_width / self.shrink_factor) + 4
         height = int(raw_height / self.shrink_factor) + 4
 
@@ -362,8 +394,7 @@ class Text(widget.BorderedWidget):
                 return (width, height), max_font
             elif not initial_dimensions[1]:
                 # Width specified, use the size of the max font, word-wrapped.
-                text_width = int((initial_dimensions[0] - 4)
-                                 * self.shrink_factor)
+                text_width = int((initial_dimensions[0] - 4) * self.shrink_factor)
                 width, height = self.size_using_font(max_font, width=text_width)
                 return (initial_dimensions[0], height), max_font
             else:
@@ -427,10 +458,20 @@ class Text(widget.BorderedWidget):
 
         self.font.set_bold(self.bold)
         # Print the string itself.
-        print_string(self.surface, self.text, (3, 2), self.font, styles,
-                     self.align, self.valign, self.real_size, self.wrap)
+        print_string(
+            self.surface,
+            self.text,
+            (3, 2),
+            self.font,
+            styles,
+            self.align,
+            self.valign,
+            self.real_size,
+            self.wrap,
+        )
         self.font.set_bold(False)
 
+
 def text_changed(self):
     if self.text is None:
         new_len = 0
@@ -441,20 +482,24 @@ def text_changed(self):
         self.needs_resize = True
     self.needs_redraw = True
 
+
 class FastText(Text):
     """
-       Reduces font searches by assuming a monospace font and single-line text.
+    Reduces font searches by assuming a monospace font and single-line text.
     """
+
     _text = widget.call_on_change("__text", text_changed)
     old_len = 0
     maybe_needs_refont = False
 
+
 class EditableText(widget.FocusWidget, Text):
     cursor_pos = widget.causes_redraw("_cursor_pos")
+
     def __init__(self, parent, *args, **kwargs):
         self.allows_new_line = kwargs.pop("allows_new_line", False)
         self.allowed_characters = kwargs.pop("allowed_characters", None)
-        
+
         super(EditableText, self).__init__(parent, *args, **kwargs)
 
         if self.text is None:
@@ -478,13 +523,15 @@ class EditableText(widget.FocusWidget, Text):
         assert event.type == pygame.KEYDOWN
         if event.key == pygame.K_BACKSPACE:
             if self.cursor_pos > 0:
-                self.text = self.text[:self.cursor_pos - 1] \
-                            + self.text[self.cursor_pos:]
+                self.text = (
+                    self.text[: self.cursor_pos - 1] + self.text[self.cursor_pos :]
+                )
                 self.cursor_pos -= 1
         elif event.key == pygame.K_DELETE:
             if self.cursor_pos < len(self.text):
-                self.text = self.text[:self.cursor_pos] \
-                + self.text[self.cursor_pos + 1:]
+                self.text = (
+                    self.text[: self.cursor_pos] + self.text[self.cursor_pos + 1 :]
+                )
         elif event.key == pygame.K_LEFT:
             self.cursor_pos = max(0, self.cursor_pos - 1)
         elif event.key == pygame.K_RIGHT:
@@ -497,23 +544,38 @@ class EditableText(widget.FocusWidget, Text):
             return
         elif event.unicode:
             char = event.unicode
-            if char in (u"\r\n", u"\n", u"\r", u"\v", u"\f", u"\x1e", 
-                        u"\x1c", u"\x1d", u"\x85", u"\u2028", u"\u2029"):
+            if char in (
+                "\r\n",
+                "\n",
+                "\r",
+                "\v",
+                "\f",
+                "\x1e",
+                "\x1c",
+                "\x1d",
+                "\x85",
+                "\u2028",
+                "\u2029",
+            ):
                 if not self.allows_new_line:
                     return
                 char = "\n"
-            if self.allowed_characters is not None and char not in self.allowed_characters:
+            if (
+                self.allowed_characters is not None
+                and char not in self.allowed_characters
+            ):
                 return
 
-            self.text = self.text[:self.cursor_pos] + char \
-                        + self.text[self.cursor_pos:]
+            self.text = (
+                self.text[: self.cursor_pos] + char + self.text[self.cursor_pos :]
+            )
             self.cursor_pos += len(char)
         else:
             return
 
         raise constants.Handled
 
-    hitbox = [0,0,0,0]
+    hitbox = [0, 0, 0, 0]
 
     def handle_click(self, event):
         if getattr(self, "collision_rect", None) is None:
@@ -539,12 +601,14 @@ class EditableText(widget.FocusWidget, Text):
         real_text_height = line_size * len(lines)
 
         line_y = 2
-        if self.valign != constants.TOP \
-           and real_text_height <= self.collision_rect.height - 4:
+        if (
+            self.valign != constants.TOP
+            and real_text_height <= self.collision_rect.height - 4
+        ):
             excess_space = self.collision_rect.height - real_text_height
             if self.valign == constants.MID:
                 line_y = excess_space // 2
-            else: # self.valign == constants.BOTTOM
+            else:  # self.valign == constants.BOTTOM
                 line_y = excess_space
 
         char_offset = 0
@@ -563,7 +627,7 @@ class EditableText(widget.FocusWidget, Text):
             excess_space = self.collision_rect.width - line_width
             if self.align == constants.CENTER:
                 line_x = excess_space // 2
-            else: # self.align == constants.LEFT
+            else:  # self.align == constants.LEFT
                 line_x = excess_space
 
         prev_width = 20000
@@ -598,12 +662,11 @@ class EditableText(widget.FocusWidget, Text):
         real_text_height = line_size * len(lines)
 
         line_y = 2
-        if self.valign != constants.TOP \
-           and real_text_height <= self.real_size[1] - 4:
+        if self.valign != constants.TOP and real_text_height <= self.real_size[1] - 4:
             excess_space = self.real_size[1] - real_text_height
             if self.valign == constants.MID:
                 line_y = excess_space // 2
-            else: # self.valign == constants.BOTTOM
+            else:  # self.valign == constants.BOTTOM
                 line_y = excess_space
 
         char_offset = 0
@@ -622,17 +685,18 @@ class EditableText(widget.FocusWidget, Text):
             excess_space = self.real_size[0] - line_width
             if self.align == constants.CENTER:
                 line_x = excess_space // 2
-            else: # self.align == constants.LEFT
+            else:  # self.align == constants.LEFT
                 line_x = excess_space
 
         line_x += self.font.size(line[:after_char])[0]
 
-        self.surface.fill( self.resolved_color, (line_x, line_y, 1, line_size))
+        self.surface.fill(self.resolved_color, (line_x, line_y, 1, line_size))
 
         if DEBUG:
             s = pygame.Surface(self.hitbox[2:]).convert_alpha()
-            s.fill( (255,0,255,100) )
-            self.surface.blit( s, self.hitbox)
+            s.fill((255, 0, 255, 100))
+            self.surface.blit(s, self.hitbox)
+
 
 class UpdateEditableText(EditableText):
     def _on_text_change(self):
@@ -644,16 +708,29 @@ class UpdateEditableText(EditableText):
         self.update_func = kwargs.pop("update_func", lambda value: None)
         super(UpdateEditableText, self).__init__(*args, **kwargs)
 
+
 class SelectableText(Text):
     selected = widget.causes_redraw("_selected")
 
-    selected_color = widget.auto_reconfig("_selected_color", "resolved", g.resolve_color_alias)
+    selected_color = widget.auto_reconfig(
+        "_selected_color", "resolved", g.resolve_color_alias
+    )
     resolved_selected_color = widget.causes_redraw("_resolved_selected_color")
-    unselected_color = widget.auto_reconfig("_unselected_color", "resolved", g.resolve_color_alias)
+    unselected_color = widget.auto_reconfig(
+        "_unselected_color", "resolved", g.resolve_color_alias
+    )
     resolved_unselected_color = widget.causes_redraw("_resolved_unselected_color")
 
-    def __init__(self, parent, pos, size, border_color = None,
-                 unselected_color = None, selected_color = None, **kwargs):
+    def __init__(
+        self,
+        parent,
+        pos,
+        size,
+        border_color=None,
+        unselected_color=None,
+        selected_color=None,
+        **kwargs
+    ):
         super(SelectableText, self).__init__(parent, pos, size, **kwargs)
 
         self.border_color = border_color or "text_border"
@@ -672,10 +749,11 @@ class SelectableText(Text):
 
 class ProgressText(SelectableText):
     progress = widget.causes_redraw("_progress")
-    
-    progress_color = widget.auto_reconfig("_progress_color", "resolved", g.resolve_color_alias)
-    resolved_progress_color = widget.causes_redraw("_resolved_progress_color")
 
+    progress_color = widget.auto_reconfig(
+        "_progress_color", "resolved", g.resolve_color_alias
+    )
+    resolved_progress_color = widget.causes_redraw("_resolved_progress_color")
 
     def __init__(self, parent, pos, size, *args, **kwargs):
         self.parent = parent
@@ -689,8 +767,9 @@ class ProgressText(SelectableText):
     def redraw(self):
         super(ProgressText, self).redraw()
         width, height = self.real_size
-        self.surface.fill(self.resolved_progress_color,
-                          (0, 0, width * self.progress, height))
+        self.surface.fill(
+            self.resolved_progress_color, (0, 0, width * self.progress, height)
+        )
         self.draw_borders()
 
 
@@ -706,10 +785,11 @@ class ChunkedText(Text):
 
         self.chunks = chunks
 
+
 class StyledText(ChunkedText):
     def resolve_styles(value):
         return tuple((g.resolve_color_alias(c), bg, u) for c, bg, u in value)
-    
+
     styles = widget.auto_reconfig("_styles", "resolved", resolve_styles)
     resolved_styles = widget.causes_redraw("_resolved_styles")
 
@@ -728,25 +808,36 @@ class StyledText(ChunkedText):
                 styles.append(list(style) + [offset])
             styles[-1][-1] = 0
 
-            print_string(self.surface, self.text, (3, 2), self.font, styles,
-                         self.align, self.valign, self.real_size, self.wrap)
+            print_string(
+                self.surface,
+                self.text,
+                (3, 2),
+                self.font,
+                styles,
+                self.align,
+                self.valign,
+                self.real_size,
+                self.wrap,
+            )
         else:
             super(StyledText, self).print_text()
 
+
 class FastStyledText(FastText, StyledText):
     pass
 
 
 def _make_prototype_handler(parent):
     def print_on_click(event):
-        if event.button != 2 and not (event.button == 1
-                                      and (pygame.key.get_mods() & pygame.KMOD_ALT)):
+        if event.button != 2 and not (
+            event.button == 1 and (pygame.key.get_mods() & pygame.KMOD_ALT)
+        ):
             return
         prefixes = ["|-", "| "]
         kids = [(child, 0) for child in parent.children]
         while kids:
             kid, depth = kids.pop()
-            further_kids = [(child, depth+1) for child in kid.children]
+            further_kids = [(child, depth + 1) for child in kid.children]
             kids += further_kids
 
             prefix = ""
@@ -754,28 +845,31 @@ def _make_prototype_handler(parent):
                 prefix = prefixes[1] * (depth - 1) + prefixes[0]
 
             print(prefix + str(kid))
+
     return print_on_click
 
+
 class ProtoWidget(EditableText):
     """Prototyping widget, for creating quick mockups.
 
-       Usage:
-       Type to name.
-       Drag to move.
-       Shift+Drag to resize.
-       Control+Drag to duplicate. (children will not duplicate)
-       Shift+Control+Drag to create a child.
+    Usage:
+    Type to name.
+    Drag to move.
+    Shift+Drag to resize.
+    Control+Drag to duplicate. (children will not duplicate)
+    Shift+Control+Drag to create a child.
+
+    Right-click to delete.
+    Middle-click or Alt+Click to write out location and size of each widget.
+    """
 
-       Right-click to delete.
-       Middle-click or Alt+Click to write out location and size of each widget.
-       """
     drag_state = -1
 
     def __init__(self, *args, **kwargs):
-        kwargs.setdefault("color", (0,0,0))
-        kwargs.setdefault("border_color", (0,0,0))
+        kwargs.setdefault("color", (0, 0, 0))
+        kwargs.setdefault("border_color", (0, 0, 0))
         kwargs.setdefault("borders", constants.ALL)
-        kwargs.setdefault("background_color", (255,255,255))
+        kwargs.setdefault("background_color", (255, 255, 255))
         super(ProtoWidget, self).__init__(*args, **kwargs)
 
     def add_hooks(self):
@@ -783,10 +877,13 @@ class ProtoWidget(EditableText):
         self.parent.add_handler(constants.DRAG, self.handle_drag)
         self.parent.add_handler(constants.CLICK, self.handle_click)
 
-        if not isinstance(self.parent, ProtoWidget) \
-           and not getattr(self.parent, "demo_mode", False):
+        if not isinstance(self.parent, ProtoWidget) and not getattr(
+            self.parent, "demo_mode", False
+        ):
             self.parent.demo_mode = True
-            self.parent.add_handler(constants.CLICK, _make_prototype_handler(self.parent))
+            self.parent.add_handler(
+                constants.CLICK, _make_prototype_handler(self.parent)
+            )
 
     def remove_hooks(self):
         self.parent.remove_handler(constants.DRAG, self.handle_drag)
@@ -795,36 +892,44 @@ class ProtoWidget(EditableText):
 
     def handle_drag(self, event):
         if self.drag_state == -1:
-            start_pos = tuple(event.pos[i]-event.rel[i] for i in range(2))
+            start_pos = tuple(event.pos[i] - event.rel[i] for i in range(2))
             if self.is_over(start_pos):
                 for child in self.children:
                     if child.is_over(start_pos):
                         self.drag_state = 0
                         return
                 real_pos = self.collision_rect[:2]
-                self.mouse_rel = tuple(real_pos[i]-start_pos[i]
-                                                     for i in range(2))
+                self.mouse_rel = tuple(real_pos[i] - start_pos[i] for i in range(2))
 
                 mod_keys = pygame.key.get_mods()
                 shift = mod_keys & pygame.KMOD_SHIFT
                 control = mod_keys & pygame.KMOD_CTRL
                 if shift and control:
                     self.drag_state = 0
-                    new_size = tuple(d/2 for d in self.size)
-                    pw=ProtoWidget(self, (0,0), new_size,
-                                  self.anchor,
-                                  background_color = self.background_color,
-                                  border_color = self.border_color,
-                                  borders = self.borders)
+                    new_size = tuple(d / 2 for d in self.size)
+                    pw = ProtoWidget(
+                        self,
+                        (0, 0),
+                        new_size,
+                        self.anchor,
+                        background_color=self.background_color,
+                        border_color=self.border_color,
+                        borders=self.borders,
+                    )
                     pw.drag_state = 0
                 elif shift:
                     self.drag_state = 2
                 elif control:
                     self.drag_state = 0
-                    pw=ProtoWidget(self.parent, self.pos, self.size, self.anchor,
-                                  background_color = self.background_color,
-                                  border_color = self.border_color,
-                                  borders = self.borders)
+                    pw = ProtoWidget(
+                        self.parent,
+                        self.pos,
+                        self.size,
+                        self.anchor,
+                        background_color=self.background_color,
+                        border_color=self.border_color,
+                        borders=self.borders,
+                    )
                     pw.drag_state = 1
                     pw.mouse_rel = self.mouse_rel
                 else:
@@ -838,7 +943,7 @@ class ProtoWidget(EditableText):
         if self.parent:
             parent_rect = self.parent.collision_rect
         else:
-            parent_rect = pygame.Rect((0,0) + g.real_screen_size)
+            parent_rect = pygame.Rect((0, 0) + g.real_screen_size)
 
         if self.drag_state == 1:
             mouse_pos = pygame.mouse.get_pos()
@@ -846,26 +951,27 @@ class ProtoWidget(EditableText):
 
             new_rel_pos = tuple(new_real_pos[i] - parent_rect[i] for i in range(2))
 
-            new_unit_pos = tuple( max(0,(new_rel_pos[i] / float(g.real_screen_size[i])))
-                                     for i in range(2))
+            new_unit_pos = tuple(
+                max(0, (new_rel_pos[i] / float(g.real_screen_size[i])))
+                for i in range(2)
+            )
 
-            new_pct_pos = tuple( int( (new_unit_pos[i] * 100) + 0.5)
-                                   for i in range(2))
+            new_pct_pos = tuple(int((new_unit_pos[i] * 100) + 0.5) for i in range(2))
 
-            self.pos = tuple(new_pct_pos[i] / 100. for i in range(2))
+            self.pos = tuple(new_pct_pos[i] / 100.0 for i in range(2))
 
             raise constants.Handled
         elif self.drag_state == 2:
             mouse_pos = pygame.mouse.get_pos()
             new_size = tuple(mouse_pos[i] - self.collision_rect[i] for i in range(2))
 
-            unit_size = tuple(max(0,new_size[i] / float(g.real_screen_size[i]))
-                                    for i in range(2))
+            unit_size = tuple(
+                max(0, new_size[i] / float(g.real_screen_size[i])) for i in range(2)
+            )
 
-            pct_size = tuple( int( (unit_size[i] * 100) + 0.5)
-                                   for i in range(2))
+            pct_size = tuple(int((unit_size[i] * 100) + 0.5) for i in range(2))
 
-            self.size = tuple(pct_size[i] / 100. for i in range(2))
+            self.size = tuple(pct_size[i] / 100.0 for i in range(2))
 
             raise constants.Handled
 
@@ -881,10 +987,11 @@ class ProtoWidget(EditableText):
                 self.parent.needs_redraw = True
         if self.drag_state > 0:
             self.drag_state = -1
-            #raise constants.Handled
+            # raise constants.Handled
         else:
             self.drag_state = -1
 
     def __str__(self):
-        return "%s pos: (%.2f, %.2f), size: (%.2f, %.2f)" % \
-           ((self.text,) + self.pos +        self.size)
+        return "%s pos: (%.2f, %.2f), size: (%.2f, %.2f)" % (
+            (self.text,) + self.pos + self.size
+        )
